==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/hotspot/jtreg/runtime/BootClassAppendProp/BootClassPathAppend.java <==
/*
 * Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8087154
 * @summary Uninitialized system property jdk.boot.class.path.append causes SIGSEGV
 * @library /test/lib
 * @modules java.base/jdk.internal.misc
 * @run driver BootClassPathAppend
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

// Test that system property jdk.boot.class.path.append is initialized.  Otherwise,
// -XX:+PrintCompilation does causes a SIGSEGV.
public class BootClassPathAppend {
  public static void main(String[] args) throws Exception {

    ProcessBuilder pb = ProcessTools.createJavaProcessBuilder(
        "-XX:+PrintCompilation", "-Xcomp", "-version");

    OutputAnalyzer output = new OutputAnalyzer(pb.start());
    output.shouldContain("java.lang.Object");
    output.shouldHaveExitValue(0);
  }
}

==> openjdk-25_25~10ea.orig.tar.xz: openjdk-25-25~10ea/test/hotspot/jtreg/runtime/BootClassAppendProp/BootClassPathAppend.java <==
/*
 * Copyright (c) 2015, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8087154
 * @summary Uninitialized system property jdk.boot.class.path.append causes SIGSEGV
 * @library /test/lib
 * @modules java.base/jdk.internal.misc
 * @run driver BootClassPathAppend
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

// Test that system property jdk.boot.class.path.append is initialized.  Otherwise,
// -XX:+PrintCompilation does causes a SIGSEGV.
public class BootClassPathAppend {
  public static void main(String[] args) throws Exception {

    ProcessBuilder pb = ProcessTools.createLimitedTestJavaProcessBuilder(
        "-XX:+PrintCompilation", "-Xcomp", "-version");

    OutputAnalyzer output = new OutputAnalyzer(pb.start());
    output.shouldContain("java.lang.Object");
    output.shouldHaveExitValue(0);
  }
}
